<!DOCTYPE TS><TS>
<context>
    <name>MainWidget</name>
    <message>
        <source>RMLSend - Macro Command Utility</source>
        <translation type="obsolete">RMLSend - Macro Command Utility</translation>
    </message>
    <message>
        <source>RML</source>
        <translation>RML</translation>
    </message>
    <message>
        <source>RML (no echo)</source>
        <translation>RML (kein echo)</translation>
    </message>
    <message>
        <source>Set Port</source>
        <translation>Port setzen</translation>
    </message>
    <message>
        <source>UDP Port:</source>
        <translation>UDP Port:</translation>
    </message>
    <message>
        <source>Command:</source>
        <translation>Befehl:</translation>
    </message>
    <message>
        <source>Response:</source>
        <translation>Antwort:</translation>
    </message>
    <message>
        <source>&amp;Send Command</source>
        <translation>Kommando &amp;senden</translation>
    </message>
    <message>
        <source>RMLSend</source>
        <translation>RMLSend</translation>
    </message>
    <message>
        <source>Invalid Port Number!</source>
        <translation>Ungültiger Portnummer!</translation>
    </message>
    <message>
        <source>Connection Failed!</source>
        <translation>Verbindung fehlgeschlagen!</translation>
    </message>
    <message>
        <source>no response</source>
        <translation>keine Antwort</translation>
    </message>
    <message>
        <source>Macro Command Utility</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
